@@ -44,9 +44,11 @@ source [file join installer manifest.tcl]
 #
 foreach x [array names Manifest] {
     if {![file exists $x]} {
-	tk_dialog .err {Zircon Installer} "Missing file - $x" error 0 Quit
-	update
-	exit 0	
+        switch dmake $Manifest($x) {} default {
+	    tk_dialog .err {Zircon Installer} "Missing file - $x" error 0 Quit
+	    update
+	    exit 0
+	}	
     }
 }
 #
