@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/support.tcl,v $
-# $Date: 1998/03/05 09:11:24 $
-# $Revision: 1.18.1.22 $
+# $Date: 1998/03/20 14:55:08 $
+# $Revision: 1.18.1.29 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -21,7 +21,8 @@ proc fail {msg} {
 }
 #
 proc zinfo {msg} {
-    .inst.info configure -text $msg
+    global NoGUI
+    if {!$NoGUI} { .inst.info configure -text $msg }
     update
 }
 #
@@ -30,8 +31,9 @@ proc Quit {} {
 }
 #
 proc Go {} {
-    catch {
-        .inst configure -cursor {watch red}
+    global NoGUI
+    if {!$NoGUI} {
+        catch {.inst configure -cursor {watch red}}
         foreach x [winfo children .inst] {
 	    catch {$x configure -cursor {watch red}}
 	    catch {$x configure -state disabled}
@@ -48,13 +50,13 @@ proc Go {} {
 	    close $fd
 	}
     }
-    catch {
+    if {!$NoGUI} {
 	foreach x [winfo children .inst] {
 	    catch {$x configure -state normal}
 	    catch {$x configure -cursor arrow}
 	}
 	.inst.btn.install configure -state normal
-	.inst configure -cursor arrow
+	catch {.inst configure -cursor arrow}
     }
 }
 #
@@ -280,8 +282,61 @@ proc zVersion {} {
 #
 [info body zircon]"
     close $fd
-    setCreator $tf$Xtn 
     return 1
 }
-
+#
+proc show {w file} {
+    if {[winfo exists $w]} {
+        raise $w
+	wm deiconify $w
+	return
+    }
+    toplevel $w
+    wm title $w "Zircon $file"
+    grid columnconfigure $w 0 -weight 1
+    scrollbar $w.vs -command "$w.txt yview"
+    scrollbar $w.hs -orient horizontal -command "$w.txt xview"
+    text $w.txt -width 80 -height 24 -yscrollcommand "$w.vs set" \
+      -xscrollcommand "$w.hs set" -wrap none
+    button $w.ok -command "destroy $w" -text OK
+    set fd [open $file r]
+    while {![eof $fd]} {
+        $w.txt insert end [gets $fd] {} "\n"
+    }
+    grid $w.txt -row 0 -column 0 -sticky nsew
+    grid $w.vs -row 0 -column 1 -sticky ns
+    grid $w.hs -row 1 -column 0 -sticky ew
+    grid $w.ok -columnspan 2
+}
+#
+proc putButtons {w} {
+    global NoGUI
+    if {!$NoGUI} {
+	grid [frame $w.sep3 -bg red] - -sticky ew -pady 2
+	frame $w.btn
+	button $w.btn.quit -text Quit -command Quit -width 12
+	button $w.btn.install -text Install -command Go -width 12
+	grid $w.btn.quit $w.btn.install
+	grid columnconfigure $w.btn 0 -weight 1
+	grid columnconfigure $w.btn 1 -weight 1
+	set col 1
+	if {[file exists CHANGES]} {
+            button $w.btn.changes -text Changes -command "show .ch CHANGES" -width 10
+	    grid $w.btn.changes -row 0 -column [incr col]
+	    grid columnconfigure $w.btn $col -weight 1
+	}
+        if {[file exists [file join doc FAQ]]} {
+            button $w.btn.faq -text FAQ -command "show .fq [file join doc FAQ]" -width 10
+	    grid $w.btn.faq -row 0 -column [incr col]
+ 	    grid columnconfigure $w.btn $col -weight 1
+       }
+        if {[file exists [file join doc COPYRIGHT]]} {
+            button $w.btn.crt -text Copying \
+	      -command "show .cp [file join doc COPYRIGHT]" -width 10
+	    grid $w.btn.crt -row 0 -column [incr col]
+	    grid columnconfigure $w.btn $col -weight 1
+        }
+        grid $w.btn -columnspan 2 -sticky ew
+    }
+}
 
