@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/unix.tcl,v $
-# $Date: 1998/03/05 09:11:25 $
-# $Revision: 1.18.1.46 $
+# $Date: 1998/03/20 14:55:10 $
+# $Revision: 1.18.1.49 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -131,24 +131,7 @@ proc install {argv} {
 #
 # Buttons
 #
-    if {!$NoGUI} {
-	grid [frame $w.sep3 -bg red] - -sticky ew -pady 2
-
-	frame $w.btn
-	button $w.btn.quit -text Quit -command Quit -width 10
-	button $w.btn.install -text Install -command Go -width 10
-	grid $w.btn.quit $w.btn.install
-	set col 1
-	if {[file exists CHANGES]} {
-            button $w.btn.changes -text Changes -command "show .ch CHANGES" -width 10
-	    grid $w.btn.changes -row 0 -column [incr col]
-	}
-        if {[file exists FAQ]} {
-            button $w.btn.faq -text FAQ -command "show .fq FAQ" -width 10
-	    grid $w.btn.faq -row 0 -column [incr col]
-        }
-        grid $w.btn -columnspan 2 -sticky ew
-    }
+    putButtons $w
 }
 #
 proc getType {} {
@@ -312,30 +295,4 @@ proc sed {file to} {
     }
     filedelete [file rootname [file tail $file]].o
 }
-#
-proc show {w file} {
-    if {[winfo exists $w]} {
-        raise $w
-	wm deiconify $w
-	return
-    }
-    toplevel $w
-    wm title $w "Zircon $file"
-    grid columnconfigure $w 0 -weight 1
-    scrollbar $w.vs -command "$w.txt yview"
-    scrollbar $w.hs -orient horizontal -command "$w.txt xview"
-    text $w.txt -width 80 -height 24 -yscrollcommand "$w.vs set" \
-      -xscrollcommand "$w.hs set" -wrap none
-    button $w.ok -command "destroy $w" -text OK
-    set fd [open $file r]
-    while {![eof $fd]} {
-        $w.txt insert end [gets $fd] {} "\n"
-    }
-    grid $w.txt -row 0 -column 0 -sticky nsew
-    grid $w.vs -row 0 -column 1 -sticky ns
-    grid $w.hs -row 1 -column 0 -sticky ew
-    grid $w.ok -columnspan 2
-}
-#
-proc setCreator {args} {}
 
