@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 1998/03/03 09:21:25 $
-# $Revision: 1.18.1.138 $
+# $Date: 1998/03/23 12:49:49 $
+# $Revision: 1.18.1.141 $
 #
 #
 package provide zircon 1.18
@@ -182,6 +182,7 @@ proc channel_show {this args} {
   	makeCBody $this $w $rchan $chan $net $args $look
 	switch {} $xc {} default { eval $xc }
 	$this defaultTags
+	$this configure -dwin [WBoard -channel $this]
 	handleOn $net POPUP [list $rchan [$this type]]
     }
     $this onShow
@@ -242,6 +243,45 @@ proc channel_addText {this tag text} {
     $this doAddText $tag $text
 }
 #
+proc getOValue {this win opt lc uc} {
+    upvar #0 $this cdata
+    if {[info exists cdata($lc)]} {
+	switch {} $cdata($lc) {} default { return $cdata($lc) }
+    }
+    switch {} [set x [option get $win $lc $uc]] {set x [$win cget -$opt]}
+    return $x
+}
+#
+proc getTValue {this win win2 opt lc uc} {
+    switch {} [set x [option get $win $lc $uc]] {
+	upvar #0 $this cdata
+    	if {[info exists $cdata($opt)]} {
+	    switch {} $cdata($opt) {} default { return $cdata($opt) }
+	}
+	if {[catch {$win2 cget -$opt} x]} {
+	    error "Weird error!!!! ($x) - please tell \
+zircon@catless.ncl.ac.uk exactly what you were doing when this happened."
+	} 
+    }
+    return $x
+}
+#
+proc setTags {this nk} {
+    global TFn TFa TFg TBg TAF TAB TBl Bl
+    set w [$this text]
+    set x "$this,$nk"
+    set ch [$this tagWindow]
+    set TFn($x) [getTValue $this $ch $w font ${nk}Font Font]
+    set TFg($x) [getTValue $this $ch $w foreground ${nk}Foreground Foreground]
+    set TBg($x) [getTValue $this $ch $w background ${nk}Background Background]
+    set TFa($x) [getTValue $this $ch $w font ${nk}ActionFont Font]
+    set TAF($x) [getTValue $this $ch $w foreground ${nk}ActionForeground Foreground]
+    set TAB($x) [getTValue $this $ch $w background ${nk}ActionBackground Background]
+    switch {} [set TBl($x) [option get $ch ${nk}Bell Bell]] {
+	if {[info exists Bl($this)]} { set TBl($x) $Bl($this) }
+    }
+}
+#
 proc tagConf {txt tag fg bg ft} {
     catch {$txt tag configure $tag -foreground $fg}
     catch {$txt tag configure $tag -background $bg}
@@ -578,7 +618,6 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 		    if {[string compare $cdata(window) [$cdata(wid) name]]} {
 		    }
 		    $cdata(wid) deregister $this
-		    catch {destroy .@zd$this}
 		}
 		switch {} [set cdata(wid) $val] {
 		    set cdata(window) {}
@@ -598,9 +637,10 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 		}
 		set cdata(monitor) $val
 	    }
+	-dwin -
 	-mwin {
-		switch {} $cdata(mwin) {} default { $cdata(mwin) delete }
-		set cdata(mwin) $val
+		switch {} $cdata($opt) {} default { $cdata($opt) delete }
+		set cdata($opt) $val
 	    }
 	-joinat {
 		checkJoinTime $this $val
@@ -624,7 +664,6 @@ proc channel_popdown {this} {
     if {[$this closeleave]} {
 	$this doLeave {}
     } {
-	if {[winfo exists .@zd$this]} { wm iconify .@zd$this }
 	handleOn [$this net] POPDOWN [list [$this lname]]
     }
 }
@@ -705,6 +744,13 @@ proc makeCTopic {this net w chan rchan idx cdx look} {
     grid $w.topic -sticky ew -column $cdx -row 0 -in $w.r$idx
 }
 #
+proc setProps {chan win} {
+    foreach x {font background foreground} {
+        switch {} [set v [$chan $x]] continue
+	$win configure -$x $v
+    }
+}
+#
 proc makeCText {this net w chan rchan idx cdx look} {
     global zLock zUnlock TypeCode
     set f [frame $w.r$idx.textFrm -borderwidth 0]
@@ -713,6 +759,7 @@ proc makeCText {this net w chan rchan idx cdx look} {
     scrollbar $f.vs -command "$ot yview"
     text $ot -yscrollcommand "setScroll $this $ot $f.vs" \
       -width [$this width] -height [$this height]
+    setProps $this $ot
     rebind $ot $net
     if {[$this jump]} { set im $zUnlock } { set im $zLock }
     button $f.jump -command "$this toggle jump $f.jump" -image $im
@@ -761,14 +808,24 @@ proc makeCText {this net w chan rchan idx cdx look} {
 #
 proc makeBindTopic {this} {
     global Fg Bg Ft BF
-    confTag [$this window].topic.entry {} $Fg($this) $Bg($this) $Ft($this) $BF($this)
+    set w [$this window].topic.entry
+    confTag $w {} $Fg($this) $Bg($this) $Ft($this) $BF($this)
+    switch {} $Fg($this) {} default { $w configure -foreground $Fg($this) }
+    switch {} $Bg($this) {} default { $w configure -background $Bg($this) }
+    switch {} $Ft($this) {} default { $w configure -font $Ft($this) }
 }
 #
 proc makeBindInfo {this} { } 
 #
 proc makeBindFlags {this} { }
 #
-proc makeBindEntry {this} { }
+proc makeBindEntry {this} {
+    global Fg Bg Ft BF
+    set w [$this window].cmd.entry
+    switch {} $Fg($this) {} default { $w configure -foreground $Fg($this) }
+    switch {} $Bg($this) {} default { $w configure -background $Bg($this) }
+    switch {} $Ft($this) {} default { $w configure -font $Ft($this) }
+}
 #
 proc makeBindControl {this} { }
 #
@@ -917,7 +974,7 @@ proc makeCtlInfo {this net w chan rchan idx look} {
 	    $omm.menu add command -label [prune $x 15] \
 	      -command "$this send {$x}"
 	}
-	$om add command -command "$this makeZDraw" -label [trans draw]
+	$om add command -command "\[$this dwin\] show" -label [trans draw]
 	if {![$this draw]} { $om entryconfigure 3 -state disabled }
 	addCTCPMenu $net $om $this
 	addSoundMenu $net $om $this
@@ -929,7 +986,7 @@ proc makeCtlInfo {this net w chan rchan idx look} {
 	$om add command -label [trans invite] -state disabled
 	$om add command  -command "channelNotice $net \[$usr name\]" \
 	  -label [trans notice]
-	$om add command -command "$this makeZDraw" -label [trans draw]
+	$om add command -command "\[$this dwin\] show" -label [trans draw]
 	if {![$this draw] || [$this isa Chat]} {
 	    $om entryconfigure last -state disabled
 	}
@@ -1065,12 +1122,12 @@ proc makeCBody {this w rchan chan net opts look} {
     }
     global BF Fg Bg Ft Bl
     set ot [$this text]
-    set BF($this) [getOValue $ot font boldFont Font]
-    set Ft($this) [getOValue $ot font font Font]
-    set Fg($this) [getOValue $ot foreground foreground Foreground]
-    set Bg($this) [getOValue $ot background background Background]
+    set BF($this) [getOValue $this $ot font boldFont Font]
+    set Ft($this) [getOValue $this $ot font font Font]
+    set Fg($this) [getOValue $this $ot foreground foreground Foreground]
+    set Bg($this) [getOValue $this $ot background background Background]
     set Bl($this) [option get [$this tagWindow] bell Bell]
-
+    $ot configure -font $Ft($this) -foreground $Fg($this) -background $Bg($this)
     foreach x $look {
 	foreach y $x { makeBind[lindex $y 0] $this }
     }
@@ -1143,7 +1200,7 @@ proc mcnDelete {this nvar reg} {
     }
     set cdata(users) {}
     set cdata(splitusers) {}
-    $this configure -wid {} -window {}
+    $this configure -wid {} -window {} -dwin {}
     if {![$this keep] && ![$this monitor]} {
 	safeUnset OType($this) [list ${nvar}([$this lname])] $this
 	rename $this {}
