@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Chat.tcl,v $
-# $Date: 1997/07/18 08:10:21 $
-# $Revision: 1.18.1.28 $
+# $Date: 1998/03/03 09:21:27 $
+# $Revision: 1.18.1.42 $
 #
 package provide zircon 1.18
 #
@@ -34,8 +34,8 @@ proc chat_nickChange {this usr nnk} {
     switch {} [set w [$this window]] return
     set net [$this net]
     $this optText NICK "*** [$usr name] is now known as $nnk"
-    if [$net me $usr] {
-	$w.uFrm.userBtn.$usr configure -text $nnk
+    if {[$net me $usr]} {
+	[$this ufrm].userBtn.$usr configure -text $nnk
 	$w.users.menu entryconfigure 3 -label $nnk
 # Check for self abuse!!
 	switch $usr [$this user] {$this nChange $nnk}
@@ -45,41 +45,40 @@ proc chat_nickChange {this usr nnk} {
 }
 #
 proc chat_nChange {this nnk} {
-    set net [$this net]
-    if [$this active] {
+    if {[$this active]} {
 	switch nil [set usr [$this user]] {} default {
 	    switch {} [set id [$usr id]] {} default { set id " ($id)"}
 	}
 	[$this wid] setTitle $this "DCC Chat with $nnk$id"
     }
-    upvar #0 CHTO$net CHTO $this cdata
+    upvar #0 CHTO[$this net] CHTO $this cdata
     set ln [string tolower $nnk]
     unset CHTO($cdata(lname))
     set CHTO($ln) $this
-    set cdata(lname) $ln
-    set cdata(name) $nnk
+    array set cdata [list\
+	lname	$ln \
+	name	$nnk \
+    ]
 }
 #
 proc chat_replace {this usr1 usr2} {$this nChange [$usr2 name]}
 #
-proc chat_call {this op args} {
-    switch {} [info procs chat_$op] {
-	return [eval channel_call $this $op $args]
-    }
-    return [eval chat_$op $this $args]
+proc chat_call {this op pars} {
+    switch {} [info procs chat_$op] { return [objCall channel $this $op $pars] }
+    return [eval chat_$op $this $pars]
 }
 #
 proc makeChat {chan} {
     global defChat
     upvar #0 currentNet net
     set this [objName Chat]
-    proc $this {args} "eval chat_call $this \$args"
+    proc $this {op args} "chat_call $this \$op \$args"
     initObj $this Channel DChat
     upvar #0 $this cdata CHTO$net CHTO
     set lchan [string tolower $chan]
-    if [catch {set def $defChat($net)}] {
+    if {[catch {set def $defChat($net)}]} {
 	global defaultNet defChan
-	if [catch {set def $defChat($defaultNet)}] {
+	if {[catch {set def $defChat($defaultNet)}]} {
 	    set def $defChan($defaultNet)
 	}
 	set b 0
@@ -100,22 +99,18 @@ proc makeChat {chan} {
 #
 proc chat_configure {this args} {
     upvar #0 $this cdata
-    while {![string match {} $args]} {
-	set val [lindex $args 1]
-	set name [lindex $args 0]
+    foreach {name val} $args {
 	switch -glob -- $name {
 	-caller { set cdata(caller) $val ; $val ref}
 	default { channel_configure $this $name $val }
 	}
-	set args [lrange $args 2 end]
     }
 }
 #
 proc chat_user {this} {
     upvar #0 $this cdata
-    switch nil $cdata(caller) {
-	return [User :: find $cdata(name) $cdata(net)]
-    } default { return $cdata(caller) }
+    switch nil $cdata(caller) {return [User :: find $cdata(name) $cdata(net)]}
+    return $cdata(caller)
 }
 #
 proc chat_isJoined {this usr} {
@@ -125,7 +120,7 @@ proc chat_isJoined {this usr} {
 #
 proc chat_delete {this} {
     upvar #0 $this cdata CHTO[set net [$this net]] CHTO
-    switch {} $cdata(logfd) {} default { close $cdata(logfd) }
+    $this doLog Close
     switch {} [set win [$this window]] {} default {
 	foreach x $cdata(users) {$x leave $this}
     }
@@ -137,11 +132,12 @@ proc chat_delete {this} {
     switch {} $cdata(sock) {} default {closeChat $this $chan $cdata(sock)}
     unset CHTO($chan) cdata
     $net deregister chats $this
+    if {[winfo exists .@dls$net]} { buildDCCList $net }
 }
 #
 proc chat_leave {this} {
     set chan [$this name]
-    if [askUser LEAVE "Leaving $chan" "Really leave DCC chat with $chan?"] {
+    if {[askUser LEAVE "Leaving $chan" "Really leave DCC chat with $chan?"]} {
 	$this doLeave {}
     }
 }
@@ -149,7 +145,7 @@ proc chat_leave {this} {
 proc Chat_make {net name} {
     upvar #0 CHTO$net CHTO
     set ln [string tolower $name]
-    if [info exists CHTO($ln)] { return $CHTO($ln) }
+    if {[info exists CHTO($ln)]} { return $CHTO($ln) }
     return [$net eval [list Chat $name]]
 }
 #
@@ -166,11 +162,18 @@ proc chat_save {this desc} { }
 proc ChatServer {usr nk} {
     set net [$usr net]
     upvar #0 AChat$net AChat
-    if [catch {socket -server "acceptChat $usr" 0} sock] { error $sock }
-    if [catch {fconfigure $sock -sockname} xx] {
+    if {[catch {socket -server "acceptChat $usr" 0} sock]} { error $sock }
+    if {[catch {fconfigure $sock -sockname} xx]} {
 	error "Cannot get port for server - $xx"
     }
     set AChat($usr) $sock
     $usr ref
     $net CTCP DCC $nk "CHAT chat [ipPack [ipAddress]] [lindex $xx 2]"
 }
+#
+proc chat_heal {this} {
+    if {[$this active]} {
+	$this flag normal
+	$this addText {} "*** netsplit : [$this name] may have left IRC."
+    }
+}
