@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
-# $Date: 1998/03/02 11:57:39 $
-# $Revision: 1.18.1.63 $
+# $Date: 1998/03/18 13:02:49 $
+# $Revision: 1.18.1.65 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -90,6 +90,7 @@ class Channel {
     histbuff	{}
     hpos	-1
     mwin	{}
+    dwin	{}
 }
 #
 class Message {
@@ -207,6 +208,7 @@ class Net "
     images	0	{bool}
     command	0	{bool}
     raw		0	{bool}
+    norestrict	0	{bool}
     helpService	{}	{nick}
     wallops	0	{bool}
     srvmsg	0	{bool}
@@ -370,5 +372,18 @@ class List { } {
     nocase	0
     listfile	{}
 }
-
+#
+class WBoard { } {
+    name	{}
+    channel	{}
+    wid		{}
+    close	0
+    mode	line
+    fill	none
+    oln		black
+    start	{}
+    last	{}
+    points	{}
+}
+#
 }
