@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/IRC.tcl,v $
-# $Date: 1998/02/26 12:23:14 $
-# $Revision: 1.18.1.46 $
+# $Date: 1998/03/23 11:27:01 $
+# $Revision: 1.18.1.47 $
 #
 package provide zircon 1.18
 #
@@ -108,6 +108,22 @@ proc ircMODE {net prefix param pargs} {
       [join $pd]]\" on channel $chan by [lindex [mung1Prefix $net $prefix] 0]"
 }
 #
+proc doPatterns {where prefix param} {
+    foreach p [$where patterns] {
+	set pt [lindex $p 0]
+	if {[regexp -nocase [lindex $pt 0] $prefix] && \
+	  [regexp [lindex $pt 1] $param]} {
+	    uplevel #0 set 0 [list $prefix]
+	    uplevel #0 set 1 [list [$where name]]
+	    if {[catch {uplevel #0 [lindex $p 1]} msg]} {
+		tellError {} {Pattern Command Error} \
+		  "Error when executing [$where name] pattern command \"[lindex $p 1]\" : $msg"
+	    }
+	    uplevel #0 unset 0 1
+	}
+    }
+}
+#
 proc ircPRIVMSG {net prefix param pargs} {
     set nkinfo [mungPrefix $net $prefix]
     set usr [lindex $nkinfo 0]
@@ -131,38 +147,29 @@ proc ircPRIVMSG {net prefix param pargs} {
 		$net inform "Message from $nk at [getDate] : $param"
 	    } {
 		handleOn $net POPUP [list $nk]
-		set id [Message :: make $net $nk]
-		if {[$id timestamp]} {set ts {}} {set ts "[getDate]\n"}
-		$id addText $usr "$ts$pfx $param"
+		set where [Message :: make $net $nk]
+		if {[$where timestamp]} {set ts {}} {set ts "[getDate]\n"}
+		$where addText $usr "$ts$pfx $param"
 	    }
-	    ditchPrefix $nkinfo
-	    return
 	} default {
 	    $where show
 	    if {![$where isJoined $usr]} {$where addUser $usr 0 0}
+	    $where addText $usr "$pfx $param"
 	}
-	set chan [$usr lname]
+	doPatterns $where $prefix $param
+	handleOn $net MSG [list $prefix $param]
     } {
 	if {[ignoreSet $ign public]} return
 	set where [Channel :: find $chan $net]
-    }
-    switch nil $where {
-	set where [$net info]
-	regsub -all "\[\x01-\x1f\]" "<$nk/$chan>" {} pfx
-    }
-    $where addText $usr "$pfx $param"
-    foreach p [$where patterns] {
-	set pt [lindex $p 0]
-	if {[regexp -nocase [lindex $pt 0] $prefix] && \
-	  [regexp [lindex $pt 1] $param]} {
-	    uplevel #0 set 0 [list $prefix]
-	    uplevel #0 set 1 [list $chan]
-	    if {[catch {uplevel #0 [lindex $p 1]} msg]} {
-		tellError {} {Pattern Command Error} \
-		  "Error when executing pattern command \"[lindex $p 1]\" : $msg"
-	    }
-	    uplevel #0 unset 0 1
+	switch nil $where {
+	    set where [$net info]
+	    regsub -all "\[\x01-\x1f\]" "<$nk/$chan>" {} pfx
 	}
+	$where addText $usr "$pfx $param"
+	doPatterns $where $prefix $param
+	set onOp PUBLIC
+	if {![$where isJoined $usr]} { set onOp PUBLIC_MSG }
+	handleOn $net $onOp [list $prefix $chan $param]
     }
     ditchPrefix $nkinfo
 }
