@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Info.tcl,v $
-# $Date: 1998/03/02 12:10:45 $
-# $Revision: 1.18.1.34 $
+# $Date: 1998/03/17 09:35:55 $
+# $Revision: 1.18.1.35 $
 #
 package provide zircon 1.18
 #
@@ -55,10 +55,10 @@ proc Info {args} {
     bind $w <Visibility> {notIdle %W}
     grid $w.vscroller -row 0 -column 1 -sticky ns
     grid $oft -row 0 -column 0 -sticky nsew
-    set BF($name) [getOValue $oft font boldFont Font]
-    set Fg($name) [getOValue $oft foreground foreground Foreground]
-    set Bg($name) [getOValue $oft background background Background]
-    set Ft($name) [getOValue $oft font font Font]
+    set BF($name) [getOValue $name  $oft font boldFont Font]
+    set Fg($name) [getOValue $name $oft foreground foreground Foreground]
+    set Bg($name) [getOValue $name $oft background background Background]
+    set Ft($name) [getOValue $name $oft font font Font]
     set Bl($name) [option get $oft bell Bell]
     confTag $oft {} $Fg($name) $Bg($name) $Ft($name) $BF($name)
     $name defaultTags
