@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Notice.tcl,v $
-# $Date: 1997/07/18 08:10:25 $
-# $Revision: 1.18.1.25 $
+# $Date: 1998/03/03 09:21:36 $
+# $Revision: 1.18.1.34 $
 #
 package provide zircon 1.18
 #
@@ -19,26 +19,26 @@ proc Notice {name args} {
     return $id
 }
 #
-proc notice_call {this op args} {
+proc notice_call {this op pars} {
     switch {} [info procs notice_$op] {
-	return [eval channel_call $this $op $args]
+	return [objCall channel $this $op $pars]
     }
-    return [eval notice_$op $this $args]
+    return [eval notice_$op $this $pars]
 }
 #
 proc makeNotice {chan net} {
     global defNotice
     set this [objName Notice]
-    proc $this {args} " eval notice_call $this \$args "
+    proc $this {op args} "notice_call $this \$op \$args "
     initObj $this Channel Notice
     set lchan [string tolower $chan]
     upvar #0 $this ndata NTO$net NTO
     switch *default* $lchan {} default {
 	[User :: make $net $chan] join $this
     }
-    if [catch {set def $defNotice($net)}] {
+    if {[catch {set def $defNotice($net)}]} {
 	global defaultNet defChan
-	if [catch {set def $defNotice($defaultNet)}] {
+	if {[catch {set def $defNotice($defaultNet)}]} {
 	    set def $defChan($defaultNet)
 	}
 	set b 0
@@ -55,6 +55,7 @@ proc makeNotice {chan net} {
 	name	$chan \
 	lname	$lchan \
 	net	$net \
+	ircIImode [$net ircIImode] \
     ]
     $net register notices $this
     set NTO($lchan) $this
@@ -79,7 +80,7 @@ proc notice_nickChange {this usr nnk} {
 #
 proc notice_nChange {this nnk} {
     set net [$this net]
-    if [$this active] {
+    if {[$this active]} {
 	[$this wid] setIcon $this $nnk
 	switch nil [set usr [User :: find [$this name] $net]] {} default {
 	    switch {} [set id [$usr id]] {} default { set id " ($id)"}
@@ -107,7 +108,7 @@ proc Notice_make {net nk} {
     upvar #0 NTO$net NTO
     set usr [User :: make $net $nk]
     set ln [string tolower $nk]
-    if [info exists NTO($ln)] { set id $NTO($ln) } {
+    if {[info exists NTO($ln)]} { set id $NTO($ln) } {
 	set id [$net eval [list Notice $nk]]
     }
     $id configure -crypt [$usr crypt]
@@ -122,13 +123,20 @@ proc Notice_find {nk net} {
     return [expr {[info exists NTO($ln)] ? $NTO($ln) : {nil}}]
 }
 #
-proc Notice_save {desc net} { defSave $desc  defNotice $net Notice }
+proc Notice_save {desc net} { defSave $desc defNotice $net Notice }
 #
 proc notice_save {this desc} { }
 #
 proc notice_leave {this} {
     set chan [$this name]
-    if [askUser LEAVE "Leaving Notice $chan" "Really close notice from $chan?"] {
+    if {[askUser LEAVE "Leaving Notice $chan" "Really close notice from $chan?"]} {
 	$this delete
     }
 }
+#
+proc notice_heal {this} {
+    if {[$this active]} {
+	$this flag normal
+	$this addText {} "*** netsplit : [$this name] may have left IRC."
+    }
+}
