@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/On.tcl,v $
-# $Date: 1997/05/07 12:46:02 $
-# $Revision: 1.18.1.11 $
+# $Date: 1998/02/10 10:48:38 $
+# $Revision: 1.18.1.12 $
 #
 package provide zircon 1.18
 #
@@ -18,11 +18,11 @@ proc on {action pattern code} {
 proc handleOn {net action pattern} {
     global zircon defaultNet
     upvar #0 OnCode$net OnCode OnCode$defaultNet Default
-    if !$zircon(o) {
+    if {!$zircon(o)} {
 	catch {foreach act $OnCode($action) {
 	    if {[checkOn $net $act $pattern] && ![$net multion]} return
 	}}
-	if [notDefaultNet] {
+	if {[notDefaultNet]} {
 	    catch {foreach act $Default($action) {
 		if {[checkOn $net $act $pattern] && ![$net multion]} return
 	    }}
@@ -33,7 +33,7 @@ proc handleOn {net action pattern} {
 proc checkOn {net act pattern} {
     foreach pat $pattern up [lindex $act 0] {
 	switch -- $up {} { set up .*}
-	if ![regexp -nocase -- $up $pat] { return 0 }
+	if {![regexp -nocase -- $up $pat]} { return 0 }
     }
     uplevel #0 set net $net
     set i 0
@@ -41,7 +41,7 @@ proc checkOn {net act pattern} {
 	uplevel #0 set $i [list $pat]
 	incr i
     }
-    if [catch {uplevel #0 [lindex $act 1]} msg] {
+    if {[catch {uplevel #0 [lindex $act 1]} msg]} {
 	tellError {} {On Command Error} \
 "Error when executing on command \"[lindex $act 1]\": $msg"
     }
