@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Sound.tcl,v $
-# $Date: 1997/05/14 19:00:12 $
-# $Revision: 1.18.1.7 $
+# $Date: 1998/02/09 16:56:51 $
+# $Revision: 1.18.1.9 $
 #
 package provide zircon 1.18
 #
@@ -13,12 +13,16 @@ proc handleSound {net usr fl} {
 	  [file join $zircon(lib) sounds]
 	switch {} [file extension $fl] {append fl .wav}
 	foreach x $dirs {
-	    if [file exists [file join $x $fl]] {set fl "[file join $x $fl]" ; break }
-	}
-	if {[regsub -all %s [$net wavplayer] $fl cmd] == 0} {
-	    append cmd " $fl"
-	}
-	if [catch {exec $cmd &} msg] {
+	    if {[file exists [file join $x $fl]]} {
+		set fl "[file join $x $fl]"
+		if {[regsub -all %s [$net wavplayer] $fl cmd] == 0} {
+		    append cmd " [list $fl]"
+		}
+		if {[catch {eval exec $cmd &} msg]} {
+		    $net inform "Error executing wav player - \"$msg\""
+		}
+		return
+	    }
 	}
     }
 }
