@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Util.tcl,v $
-# $Date: 1997/07/08 11:28:04 $
-# $Revision: 1.18.1.46 $
+# $Date: 1998/03/05 09:11:16 $
+# $Revision: 1.18.1.62 $
 #
 package provide zircon 1.18
 #
@@ -27,11 +27,18 @@ proc listmember {list val} {return [expr {[lsearch $list $val] >= 0}]}
 proc listkill {list val} {
     upvar $list lst
     if {[set x [lsearch $lst $val]] >= 0} { set lst [lreplace $lst $x $x]}
+    return $lst
+}
+#
+proc listremove {lst val} {
+    if {[set x [lsearch $lst $val]] >= 0} { set lst [lreplace $lst $x $x]}
+    return $lst
 }
 #
 proc listincl {list val} {
     upvar $list lst
-    if ![listmember $lst $val] { lappend lst $val }
+    if {![listmember $lst $val]} { lappend lst $val }
+    return $lst
 }
 #
 proc listmatch {list val} {
@@ -46,22 +53,23 @@ proc listmatch {list val} {
 proc listdel {v item} {
     upvar $v lst
     catch {set lst [lreplace $lst $item $item]}
+    return $lst
 }
 #
 proc listput {list posn val} {
     upvar $list lst
-    set lst [linsert $lst $posn $val]
+    return [set lst [linsert $lst $posn $val]]
 }
 #
 proc listupdate {list item val} {
     upvar $list lst
     while {[llength $lst] <= $item} {lappend lst {} }
-    set lst [lreplace $lst $item $item $val]
+    return [set lst [lreplace $lst $item $item $val]]
 }
 #
 proc listmove {list from to val} {
     upvar $list lst
-    set lst [linsert [lreplace $lst $from $from] $to $val]
+    return [set lst [linsert [lreplace $lst $from $from] $to $val]]
 }
 #
 # Procedure used to shorten menu labels to 10 characters. Used
@@ -74,9 +82,7 @@ proc prune {name lng} {
 }
 #
 proc killWindow {win} {
-    global Icon IconBM
-    catch {unset Icon($win)}
-    catch {unset IconBM($win)}
+    safeUnset Icon($win) IconBM($win)
     catch {destroy $win}
 }
 #
@@ -97,7 +103,7 @@ proc addCTCPMenu {net name usr} {
     menu $name.ctcp 
     set cmdlst $ctcpCmds
     switch {} [$net wavplayer] {} default { lappend cmdlst Sound }
-    if $DEBUG { lappend cmdlst Zircon }
+    if {$DEBUG} { lappend cmdlst Zircon }
     foreach cmd $cmdlst {
 	switch {{}} $usr {
 	    set prc "usersCTCP $net [string toupper $cmd]"
@@ -128,7 +134,7 @@ proc addDCCMenu {name usr} {
 }
 #
 proc makeUserMenu {chid win usr} {
-    if [winfo exists $win] { return $win }
+    if {[winfo exists $win]} { return $win }
     return [menu $win -postcommand "postUM $chid $win $usr"]
 }
 #
@@ -167,14 +173,14 @@ proc postUM {chid win usr} {
 	Message -
 	Notice -
 	Time { $win add command -label [trans $cmd] -command $ucmds($cmd) }
-	Ignore { if $nrm {addIgnoreMenu $win $usr} }
+	Ignore { if {$nrm} {addIgnoreMenu $win $usr} }
 	Finger {
-		if $nrm {
+		if {$nrm} {
 		    $win add command -label [trans finger] -command "$usr finger"
 		}
 	   }
 	Silence {
-		if [$net undernet] {
+		if {[$net undernet]} {
 		    $win add cascade -label [trans silence] \
 		      -menu $win.silence
 		    menu $win.silence -tearoff 0
@@ -187,7 +193,7 @@ proc postUM {chid win usr} {
 	}
     }
     addPluginMenu $win $net $chid $usr
-    if $nrm {
+    if {$nrm} {
 	set st [expr {(![$net restricted] && [$chid operator]) ? "normal" : "disabled"}]
 	foreach cmd $Ops(chanop) {
 	    switch $cmd {
@@ -228,11 +234,12 @@ proc invert {b} {
 }
 #
 proc makeLB {win args} {
-    frame $win -borderwidth 0
+    frame $win -borderwidth 0 -relief flat
     grid columnconfigure $win 0 -weight 1
     grid rowconfigure $win 0 -weight 1
-    scrollbar $win.vs -command "$win.l yview"
-    scrollbar $win.hs -command "$win.l xview" -orient horizontal
+    scrollbar $win.vs -command "$win.l yview" -relief sunken -highlightthickness 0
+    scrollbar $win.hs -command "$win.l xview" -orient horizontal \
+      -relief sunken -highlightthickness 0
     eval listbox $win.l -xscrollcommand "{ghsSet $win.hs}" \
       -yscrollcommand "{gvsSet $win.vs}" -selectmode single -setgrid 1 $args
     grid $win.l -row 0 -column 0 -sticky nsew
@@ -278,6 +285,7 @@ proc switchFrame {ctl net title args} {
     global zDIOff
     set rq [llength [grid slaves $ctl -column 0]]
     grid rowconfigure $ctl $rq -weight 1 -minsize 30
+    grid columnconfigure $ctl 0 -weight 1
     grid [set mn [frame $ctl.$net -borderwidth 0]] -sticky nsew \
       -row $rq -column 0
 #    switch {} $args {} default {
@@ -314,13 +322,39 @@ proc exposeFrame {ctl net} {
       $zDIOn	{set im $zDIOff } \
       $zDIOn1	{set im $zDIOff1 }
     $w.ctl configure -image $im
-    if $forget {
+    if {$forget} {
 	grid forget $ctl.$net.bdy
     } {
 	grid $ctl.$net.bdy -sticky nsew -row 2 -column 0
     }
 }
 #
+proc openFrame {ctl net} {
+    global zDIOff zDIOn zDIOff1 zDIOn1
+    set w $ctl.$net.exp
+    set forget 1
+    $w.ctl configure -image $zDIOn1
+    $w.title configure -fg red
+    grid $ctl.$net.bdy -sticky nsew -row 2 -column 0
+}
+#
+proc closeFrame {ctl net} {
+    global zDIOff zDIOn zDIOff1 zDIOn1
+    set w $ctl.$net.exp
+    set forget 1
+    $w.ctl configure -image $zDIOff
+    $w.title configure -fg black
+    grid forget $ctl.$net.bdy
+}
+#
+proc hilightFrame {ctl net} {
+    $ctl.$net.exp.title configure -fg red
+}
+#
+proc lolightFrame {ctl net} {
+    $ctl.$net.exp.title configure -fg black
+}
+#
 proc retitleFrame {ctl net title args} {
     global zDIOff1 zDIOff zDIOn zDIOn1
     append ctl .$net.exp
@@ -364,6 +398,12 @@ proc getDate {} { return [clock format [clock seconds]] }
 #
 proc convTime {t} { return [clock format $t] }
 #
+proc ipPack {ip} {
+    set val 0
+    foreach x [split $ip .] { set val [expr {($val << 8) | ($x & 0377)}] }
+    return [format %u $val]
+}
+#
 proc IPaccept {p1 p2 args} {
     global hostIPaddress
     set hostIPaddress $p2
@@ -372,7 +412,7 @@ proc IPaccept {p1 p2 args} {
 #
 proc ipAddress {} {
     global hostIPaddress
-    if ![info exists hostIPaddress] {
+    if {![info exists hostIPaddress]} {
 	set hostIPaddress {}
 	set sock [socket -server IPaccept 0]
 	set sock2 [socket [info hostname] \
@@ -393,21 +433,29 @@ proc acceptCon {cmd p1 p2} { fileevent $p1 readable $cmd }
 #
 proc server {cmd} {
     set fd [socket -server "acceptCon {$cmd}" 0]
-    if [catch {fconfigure $fd -sockname} xx] {
+    if {[catch {fconfigure $fd -sockname} xx]} {
 	error "Cannot get port for server - $xx"
     }
     return [list $fd [lindex $xx 2]]
 }
 #
 proc zping {res} {
-    if ![regexp {^[0-9]+$} [string trim $res]] { return $res }
-    return [expr {[clock seconds] - $res}]
+    if {![regexp {^[0-9]+$} [string trim $res]]} { return $res }
+    if {[catch  {set v [expr {[clock seconds] - $res}]}]} {
+	return $res
+    }
+    return $v
 }
 #
 proc safeClean {txt} {return [split [string trim $txt]]}
 #
 proc notIdle {win args} {
-    catch {$args configure -idle 0}
+    switch {} $args {
+	global currentNet
+	catch {$currentNet configure -idle 0}
+    } default {
+	catch {$args configure -idle 0}
+    }
     catch {[Window :: id $win] extendTime}
 }
 #
@@ -418,23 +466,23 @@ proc popup {win} {
 }
 #
 proc markButton {name which} {
-    if ![winfo exists $name] return
-    foreach opt {font foreground background activeForeground \
-      activeBackground} {
-	set uopt [capitalise $opt]
+    if {![winfo exists $name]} return
+    foreach {opt uopt lopt} {font Font font \
+	foreground Foreground foreground \
+	background Background background \
+	activeForeground ActiveForeground activeforeground \
+	activeBackground ActiveBackground activebackground} {
 	set fopt $which[switch {} $which {set opt} default {set uopt}]
-	set lopt [string tolower $opt]
 	switch {} [set cl [option get $name $fopt $uopt]] {
 	    switch {} $which {
 		switch {} [set cl [lindex [$name conf -$lopt] 3]] {} default {
-		    if [catch {$name conf -$lopt $cl}] {
+		    if {[catch {$name conf -$lopt $cl}]} {
 			tellError {} {Option Error} "$opt configuration error - \"$msg\""
 		    }
 		}
 	    }
 	} default {
-	
-	    if [catch {$name conf -$lopt $cl} msg] {
+	    if {[catch {$name conf -$lopt $cl} msg]} {
 		tellError {} {Option Error} "$opt configuration error - \"$msg\""
 	    }
 	} \
@@ -445,7 +493,7 @@ proc markButton {name which} {
 proc lchange {x} {
     set inc 20
     if {(255 - $x) < 20} { set inc -20 }
-    return [expr (($x + $inc) & 255)]
+    return [expr {(($x + $inc) & 255)}]
 }
 #
 proc lighten {w cl} {
@@ -456,10 +504,10 @@ proc lighten {w cl} {
 #
 proc markEntry {name index which} {
     if {![winfo exists $name] || $index == -1} return
-    foreach opt {font background activeBackground} {
-	set uopt [capitalise $opt]
+    foreach {opt uopt lopt} {font Font font \
+      background Background background \
+      activeBackground ActiveBackground activebackground} {
 	set fopt $which[switch {} $which {set opt} default {set uopt}]
-	set lopt [string tolower $opt]
 	switch {} [set cl [option get $name $fopt $uopt]] {
 	    switch {} $which {
 		switch {} [set cl [lindex [$name conf -$lopt] 3]] {} default {
@@ -498,7 +546,7 @@ proc bgIns {col chan prt} {
 	    set indx [$w index insert]
 	}
     }
-    if [regexp "\003\[0-9\]\[0-9\]?$" [string range $txt 0 [incr indx -1]]] {
+    if {[regexp "\003\[0-9\]\[0-9\]?$" [string range $txt 0 [incr indx -1]]]} {
 	set str ,$col
     } {
 	set str "\0031,$col"
@@ -507,17 +555,14 @@ proc bgIns {col chan prt} {
 }
 #
 proc palIns {char chan prt} {
-    switch $prt {
-    Topic { set w [$chan window].topic.entry }
-    Entry { set w [$chan window].cmd.entry }
-    default {set w $prt}
-    }
+    switch $prt Topic { set w [$chan window].topic.entry } \
+      Entry { set w [$chan window].cmd.entry } default {set w $prt}
     $w insert insert $char
 }
 #
 proc popPalette {m chn prt col x y} {
     global mIRCCol
-    if ![winfo exists $m] {
+    if {![winfo exists $m]} {
 	menu $m -tearoff 0
 	$m add command -label Bold -command "palIns \002 {$chn} {$prt}"
 	$m add command -label Inverse -command "palIns \026 {$chn} {$prt}"
@@ -542,7 +587,7 @@ proc popPalette {m chn prt col x y} {
 }
 #
 proc makePalette {w chn prt name ft col} {
-    if [winfo exists $w] {popup $w ; return} 
+    if {[winfo exists $w]} {popup $w ; return} 
     global mIRCCol Ft
     killWindow $w
     toplevel $w -class Zircon
@@ -603,11 +648,11 @@ proc uExpand {w net chid} {
     set hd [string tolower [string range $txt $start $end]]
     set hits($w) {}
     foreach u [$chid users] {
-	if [string match $hd* [$u lname]] {lappend hits($w) $u}
+	if {[string match $hd* [$u lname]]} {lappend hits($w) $u}
     }
     switch {} $hits($w) { unset hits($w) ; return {} }
     if {[llength $hits($w)] > 1} {
-	set m [menu .@[newName Exp] -transient 1 -tearoff 0]
+	set m [menu .@[newName Exp] -tearoff 0]
 	set f 0
 	foreach u $hits($w) {
 	    set cmd "set pick($w) $u ; destroy $m"
@@ -636,3 +681,15 @@ proc evenGrid {w what start end} {
 	grid ${what}configure $w $i -weight 1
     }
 }
+#
+proc fullName {file} {
+    switch [file pathtype $file] {
+    relative { return [file join [pwd] $file] }
+    }
+    return $file
+}
+#
+proc safeUnset {args} { foreach x $args { catch {uplevel #0 unset $x} msg } }
+#
+proc safeDestroy {args} { foreach x $args { catch {destroy $x} } }
+
