@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confTab.tcl,v $
-# $Date: 1998/02/09 16:57:03 $
-# $Revision: 1.18.1.10 $
+# $Date: 1998/03/20 14:39:10 $
+# $Revision: 1.18.1.11 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -36,16 +36,18 @@ proc configWin {net} {
     tabShow $net $lastConf($net)
 }
 #
+set Tabs {Nicknames IRCNames Servers Channels Messages Notices Chat DCC \
+      Friends Ignores Info}
+#
 proc drawTabs {net} {
-    global lastConf
+    global lastConf Tabs
     set w .@conf$net.page
     set normalColor [$w cget -selectbackground]
     set activeColor [$w cget -background]
     set margin 6
     set x 2
     set maxh 0
-    foreach name {Nicknames IRCNames Servers Channels Messages Notices Chat DCC \
-      Friends Ignores Info} {
+    foreach name $Tabs {
 	set id [$w create text [expr $x+$margin+2] [expr -0.5*$margin]\
 	  -anchor sw -text [trans $name] -tags $name]
 	set bbox [$w bbox $id]
@@ -71,13 +73,13 @@ proc drawTabs {net} {
 #
 proc tabShow {net pane} {
     global t option pref lastConf
-     if {[listmember [set cc [$net confChange]] $lastConf($net)]} {
-       if {![askUser {} {Save Changes} "You have unsaved changes for\
- $lastConf($net) which will be lost if you change to $pane. Really\
- change to $pane?"]} return
-       listkill cc $lastConf($net)
-       $net configure -confChange $cc
-    }
+#    if {[listmember [set cc [$net confChange]] $lastConf($net)]} {
+#       if {![askUser {} {Save Changes} "You have unsaved changes for\
+# $lastConf($net) which will be lost if you change to $pane. Really\
+# change to $pane?"]} return
+#       listkill cc $lastConf($net)
+#       $net configure -confChange $cc
+#    }
     set w .@conf$net
     $w.page itemconfigure tab -fill [$w.page cget -selectbackground]
     $w.page itemconfigure tab-$pane -fill [$w.page cget -background]
@@ -94,31 +96,39 @@ proc tabShow {net pane} {
     update idletasks
 }
 #
+proc confUnchange {net tab} {
+   set cc [$net confChange]
+   listkill cc $tab
+   $net configure -confChange $cc
+}
+#
 proc confrevclean {net which} {
     catch {uplevel #0 unset new$net}
+    global Tabs
     switch $which {
     Servers {
-	global newSv delSv
-	foreach v $newSv($net) { $v delete }
-	unset newSv($net) delSv($net)
-	Server :: cleanup new
-    }
+	    global newSv delSv
+	    foreach v $newSv($net) { $v delete }
+	    unset newSv($net) delSv($net)
+	    Server :: cleanup new
+        }
 
     Channels {
-	global newChn delChn
-	foreach v $newChn($net) {
+	    global newChn delChn
+	    foreach v $newChn($net) {
 	    if {![$v sys]} { $v delete }
-	}
-	Channel :: cleanup $net
-	unset newChn($net) delChn($net)
-    }
+	    }
+	    Channel :: cleanup $net
+	    unset newChn($net) delChn($net)
+        }
 
     Friends {
-	global newFrd delFrd
-	foreach v $newFrd($net) { $v delete }
-	unset newFrd($net) delFrd($net)
-    }
+	    global newFrd delFrd
+	    foreach v $newFrd($net) { $v delete }
+	    unset newFrd($net) delFrd($net)
+        }
     }
+    if {[listmember $Tabs $which]} { confUnchange $net $which }
 }
 #
 proc confdismiss {net} {
@@ -127,7 +137,9 @@ proc confdismiss {net} {
 	if {![askUser SAVECONF {Save Changes} "You have unsaved changes. Really	dismiss?"]} return
     }
     killWindow .@conf$net
-    foreach x [$net confChange] { confrevclean $net $x }
+    foreach x [$net confChange] {
+        confrevclean $net $x 
+    }
 }
 #
 proc confrevert {net} {
