@@ -1,12 +1,12 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/errors.tcl,v $
-# $Date: 1997/05/16 09:42:04 $
-# $Revision: 1.18.1.15 $
+# $Date: 1998/02/10 10:48:41 $
+# $Revision: 1.18.1.17 $
 #
 package provide zircon 1.18
 #
 proc irc401 {net prefix param pargs} {
-    if [[set msg [Message :: find [set chn [lindex $pargs 1]] $net]] active] {
+    if {[[set msg [Message :: find [set chn [lindex $pargs 1]] $net]] active]} {
 	$msg addText @ERROR "*** $chn is not on IRC"
     } {
 	$net errmsg "$chn - $param"
@@ -15,12 +15,12 @@ proc irc401 {net prefix param pargs} {
 	upvar #0 Offer$net Offer
 	catch {
 	    foreach v $Offer($usr) { killDel Offer$net $usr [lindex $v 1] }
-	} msg
+	}
     }
 }
 #
 proc irc404 {net prefix param pargs} {
-    if [[set chn [Channel :: find [set chan [lindex $pargs 1]] $net]] active] {
+    if {[[set chn [Channel :: find [set chan [lindex $pargs 1]] $net]] active]} {
 	$chn addText @ERROR "*** $param"
     } {
 	$net errmsg "Cannot send to channel $chan"
@@ -64,7 +64,7 @@ proc tryNick {net nk} {
 #
 proc cantUseNick {net prefix param pargs msg} {
     set unk [lindex $pargs 1]
-    if [$net startup] {
+    if {[$net startup]} {
 	global user
 	$net fast
 	set nk $user
@@ -84,7 +84,7 @@ proc cantUseNick {net prefix param pargs msg} {
 }
 #
 proc irc442 {net prefix param pargs} {
-    if [[set ch [Channel :: find [set nm [lindex $pargs 1]] $net]] active] {
+    if {[[set ch [Channel :: find [set nm [lindex $pargs 1]] $net]] active]} {
 	$ch delete
     } {
 	tellError $net {Channel Error} "$nm $param [lindex $pargs 2]"
@@ -93,7 +93,7 @@ proc irc442 {net prefix param pargs} {
 
 proc irc443 {net prefix param pargs} {
     set who [lindex $pargs 1]
-    if [[set ch [Channel :: find [set cn [lindex $pargs 2]] $net]] active] {
+    if {[[set ch [Channel :: find [set cn [lindex $pargs 2]] $net]] active]} {
 	$ch addText @ERROR "*** $who $param $cn"
     } {
 	tellError $net {Invite Error} "$who $param $cn"
@@ -102,12 +102,12 @@ proc irc443 {net prefix param pargs} {
 
 proc irc471 {net prefix param pargs} {
     set chn [Channel :: find [set chan [lindex $pargs 1]] $net]
-    if [tk_dialog .@f$net {Channel Full} "Channel ${chan} is full!" \
-      error 0 OK {Try Again}] {$chn sendJoin}
+    if {[tk_dialog .@f$net {Channel Full} "Channel ${chan} is full!" \
+      error 0 OK {Try Again}]} {$chn sendJoin}
 }
 
 proc irc473 {net prefix param pargs} {
-    if [[set ch [Channel :: find [lindex $pargs 1] $net]] active] {
+    if {[[set ch [Channel :: find [lindex $pargs 1] $net]] active]} {
 	$ch addText @ERROR "*** \007Channel is invitation only!"
     } {
 	tellError $net {Invitation Only} "Channel [lindex $pargs 1] is invitation only!"
@@ -115,7 +115,7 @@ proc irc473 {net prefix param pargs} {
 }
 #
 proc irc474 {net prefix param pargs} {
-    if [[set ch [Channel :: find [lindex $pargs 1] $net]] active] {
+    if {[[set ch [Channel :: find [lindex $pargs 1] $net]] active]} {
 	$ch flag disabled
 	$ch addText @ERROR "*** \007You are banned from this channel!"
     } {
