@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/main.tcl,v $
-# $Date: 1998/02/26 11:41:04 $
-# $Revision: 1.18.1.78 $
+# $Date: 1998/03/17 09:36:02 $
+# $Revision: 1.18.1.79 $
 #
 package provide zircon 1.18
 #
@@ -46,37 +46,6 @@ proc setState {name pick state} {
     }
 }
 #
-proc getOValue {win opt lc uc} {
-    switch {} [set x [option get $win $lc $uc]] {set x [$win cget -$opt]}
-    return $x
-}
-#
-proc getTValue {win win2 opt lc uc} {
-    switch {} [set x [option get $win $lc $uc]] {
-	if {[catch {$win2 cget -$opt} x]} {
-	    error "Weird error!!!! ($x) - please tell \
-zircon@catless.ncl.ac.uk exactly what you were doing when this happened."
-	}
-    }
-    return $x
-}
-#
-proc setTags {this nk} {
-    global TFn TFa TFg TBg TAF TAB TBl Bl
-    set w [$this text]
-    set x "$this,$nk"
-    set ch [$this tagWindow]
-    set TFn($x) [getTValue $ch $w font ${nk}Font Font]
-    set TFg($x) [getTValue $ch $w foreground ${nk}Foreground Foreground]
-    set TBg($x) [getTValue $ch $w background ${nk}Background Background]
-    set TFa($x) [getTValue $ch $w font ${nk}ActionFont Font]
-    set TAF($x) [getTValue $ch $w foreground ${nk}ActionForeground Foreground]
-    set TAB($x) [getTValue $ch $w background ${nk}ActionBackground Background]
-    switch {} [set TBl($x) [option get $ch ${nk}Bell Bell]] {
-	if {[info exists Bl($this)]} { set TBl($x) $Bl($this) }
-    }
-}
-#
 #	0 white       8 yellow
 #	1 black       9 lightgreen
 #	2 blue       10 cyan
