@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc2.tcl,v $
-# $Date: 1998/02/10 10:48:45 $
-# $Revision: 1.18.1.27 $
+# $Date: 1998/03/17 09:36:05 $
+# $Revision: 1.18.1.28 $
 #
 #
 package provide zircon 1.18
@@ -76,7 +76,7 @@ proc /CTCP {net chid arg} {
     switch * $nk {set nk [$chid name]}
     switch [set cmd [string toupper [lindex $arg 1]]] {
     PING { $net CTCP PING $nk [ZPING] }
-    CLIENTINFO {$net CTCP $CMD $nk [lindex $arg 2]}
+    CLIENTINFO {$net CTCP $cmd $nk [lindex $arg 2]}
     ERRMSG -
     SOUND -
     ACTION -
