@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1998/02/10 13:27:05 $
-# $Revision: 1.18.1.46 $
+# $Date: 1998/03/11 10:52:08 $
+# $Revision: 1.18.1.48 $
 #
 package provide Dcc 1.18
 #
@@ -40,46 +40,45 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 		tellError {} {File error} "Cannot write file $file."
 		return 0
 	    }
-	    switch $posn [file size $file] {} default {
-	    switch [tk_dialog .@dg$net {DCC Get} \
-	      "File \"$file\" already exists. Select the action you want to take." \
-	      warning 0 Overwrite Resume {Rename incoming} \
-	      {Rename Existing} Cancel] { 
-	    0 {}
-	    1 {
-		    $net CTCP DCC [$usr name] "RESUME [file tail $file] $port $posn"
-		    global Resume
-		    if {![info exists Resume($usr)]} {$usr ref}
-		    lappend Resume($usr) \
-		      [list $file $addr $port $leng $posn]
-		    return 0
-		}
-	    2 {
-		    global DCCR
-		    set DCCR({$net,$file}) {}
-		    tkwait window [mkEntryBox {} {Rename incoming} \
-		      "Enter new name for incoming $file:" \
-		      [list [list filename $file]] \
-		      [list ok "set DCCR([list $net,$file])"] \
-		      [list cancel {}]]
-		    set v $DCCR({$net,$file})
-		    unset DCCR({$net,$file})
-		    switch {} $v return
-		    set file $v
-		}
-	    3 {
-		    global DCCR
-		    set DCCR($net,$file) 0
-		    tkwait window [mkEntryBox {} {Rename} \
-		      "Enter new name for $file:" \
-		      [list [list filename $file]] \
-		      [list ok "dodRename $net [list $file]"] [list cancel {}]]
-		    set v $DCCR($net,$file);
-		    unset DCCR($net,$file)
-		    if {!$v} {return 0}
-		}
-	    4 {return 0}
-	    }
+	    switch $posn [set fp [file size $file]] {} default {
+	        switch [tk_dialog .@dg$net {DCC Get} \
+	          "File \"$file\" already exists. Select the action you want to take." \
+	          warning 0 Overwrite Resume {Rename incoming} \
+	          {Rename Existing} Cancel] { 
+	        0 {}
+	        1 {
+		      $net CTCP DCC [$usr name] "RESUME [file tail $file] $port $fp"
+		      global Resume
+		      if {![info exists Resume($usr)]} {$usr ref}
+		      lappend Resume($usr) [list $file $addr $port $leng $fp]
+		      return 0
+		  }
+	        2 {
+		      global DCCR
+		      set DCCR({$net,$file}) {}
+		      tkwait window [mkEntryBox {} {Rename incoming} \
+		        "Enter new name for incoming $file:" \
+		        [list [list filename $file]] \
+		        [list ok "set DCCR([list $net,$file])"] \
+		        [list cancel {}]]
+		      set v $DCCR({$net,$file})
+		      unset DCCR({$net,$file})
+		      switch {} $v return
+		      set file $v
+		  }
+	        3 {
+		      global DCCR
+		      set DCCR($net,$file) 0
+		      tkwait window [mkEntryBox {} {Rename} \
+		        "Enter new name for $file:" \
+		        [list [list filename $file]] \
+		        [list ok "dodRename $net [list $file]"] [list cancel {}]]
+		      set v $DCCR($net,$file);
+		      unset DCCR($net,$file)
+		      if {!$v} {return 0}
+		  }
+	        4 {return 0}
+	        }
 	    }
 	}
 	set file [file join [file dirname $file] [file tail $file]]
