@@ -1,40 +1,14 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/send.tcl,v $
-# $Date: 1997/07/18 08:01:37 $
-# $Revision: 1.18.1.13 $
+# $Date: 1998/02/26 15:51:32 $
+# $Revision: 1.18.1.23 $
 #
 package provide Dcc 1.18
 #
-proc acceptSend {net key file usr chan hst port} {
-    global zircon
-    upvar #0 Offer$net Offer Send$net Send
-    set x [lsearch $Offer($usr) "$key *"]
-    set v [lindex $Offer($usr) $x]
-    close [lindex $v 2]
-    if [catch {set fd [open "|[file join $zircon(lib) plugins Dcc dccsend] $file\
-      [lindex $v 4] $usr <@$chan 2>@$chan" r]} msg] {
-	tellError {} {Prog error} "Cannot run DCC helper program \
-dccsend - \"$msg\"
-Check your installation"
-	close $chan
-	return
-    }
-    catch {fconfigure $fd -buffering line -translation lf}
-    fileevent $fd readable "handleInfo $net $fd"
-    set v [list $fd $file [lindex $v 3] [lindex $v 4]]
-    close $chan
-    $usr ref
-    lappend Send($usr) $v
-    listdel Offer($usr) $x
-    switch -- $Offer($usr) {} {unset Offer($usr) ; $usr deref}
-    if [winfo exists .@dls$net] { buildDCCList $net }
-    dccWindow $fd $usr Send $file
-}
-#
 proc DCCSend {usr file} {
     switch {} $file return
-    if [file exists $file] {
-	if ![file readable $file] {
+    if {[file exists $file]} {
+	if {![file readable $file]} {
 	    tellError {} {File error} "Cannot read file \"$file\"."
 	    return
 	}
@@ -45,14 +19,14 @@ proc DCCSend {usr file} {
 	upvar #0 Offer$net Offer
 	set ky [newName Scon]
 	set sock [socket -server "acceptSend $net $ky $file $usr" 0]
-	if [catch {fconfigure $sock -sockname} xx] {
+	if {[catch {fconfigure $sock -sockname} xx]} {
 	    error "Cannot get port for server - $xx"
 	}
-	if ![info exists Offer($usr)] { $usr ref }
+	if {![info exists Offer($usr)]} { $usr ref }
 	lappend Offer($usr) [list $ky $file $sock [lindex $xx 2] 0 0]
 	$net CTCP DCC [$usr name] \
 	  "SEND $xfile [ipPack [ipAddress]] [lindex $xx 2] [file size $file]"
-	if [winfo exists .@dls$net] { buildDCCList $net }
+	if {[winfo exists .@dls$net]} { buildDCCList $net }
     } {
 	tellError {} {File error} "File \"$file\" does not exist."
     }
@@ -63,8 +37,9 @@ proc handleInfo {net conn} {
 	catch {close $conn}
     } {
 	zIn "! $msg" $net
-	regsub -all {[\\{\"}]} $msg {\\&} sp
-	switch -- [set who [lindex $sp 5]] {} {error "Bad Info line - {$msg}"}
+#	regsub -all {[\\{\"}]} $msg {\\&} sp
+	set sp [split $msg]
+	switch {} [set who [lindex $sp 5]] {error "Bad Info line - {$msg}"}
 	set msg [join [lreplace [lrange $sp 1 end] 4 4 [$who name]]]
 	switch -glob -- $msg {
 	{DCC Get prog*} -
@@ -73,13 +48,9 @@ proc handleInfo {net conn} {
 		  [lindex $sp 8] [lindex $sp 9]}
 	    }
 	{DCC Send*} -
-	{DCCError Send*} {
-		endDCC Send $who $conn $net $msg
-	    }
+	{DCCError Send*} {endDCC Send $who $conn $net $msg}
 	{DCCError Get*} -
-	{DCC Get*} {
-		endDCC Get $who $conn $net $msg
-	    }
+	{DCC Get*} {endDCC Get $who $conn $net $msg}
 	default {
 		mkInfoBox $net DCCINFO .@dcc$conn {DCC Info} "WEIRD ERROR : $msg"
 	    }
@@ -87,18 +58,18 @@ proc handleInfo {net conn} {
     }
 }
 #
-proc endDCC {type who conn net msg} {
-    global $type$net
-    set x [lsearch [set ${type}${net}($who)] "$conn *"]
-    listdel ${type}${net}($who) $x
-    $who deref
-    switch -- [set ${type}${net}($who)] {} {unset ${type}${net}($who)}
-    if [winfo exists .@dls$net] { buildDCCList $net }
-    if ![winfo exists .@$conn] {
+proc endDCC {type who conn net msg args} {
+    upvar #0 $type$net gsnet
+    set x [lsearch $gsnet($who) "$conn *"]
+    set file [lindex [lindex $gsnet($who) $x] 1]
+    listdel gsnet($who) $x
+    switch {} $gsnet($who) {unset gsnet($who)}
+    if {[winfo exists .@dls$net]} { buildDCCList $net }
+    if {![winfo exists .@$conn]} {
 	$net inform $msg
     } {
 	catch {destroy .@$conn.slide .@$conn.txt .@$conn.txt2}
-	if [winfo exists .@$conn.done] {
+	if {[winfo exists .@$conn.done]} {
 	    .@$conn.done configure -text $msg
 	} {
 	    grid [label .@$conn.done -text $msg] -row 0 -sticky ew -padx 10 -pady 10
@@ -106,31 +77,19 @@ proc endDCC {type who conn net msg} {
 	.@$conn.cancel configure -text [trans dismiss] -command "destroy .@$conn"
     }
     close $conn
-}
-#
-proc startGet {sk net file usr leng posn} {
-    global zircon
-    zOut "! dccget $file $usr $leng $posn" $net
-    if [catch {open "|[file join $zircon(lib) plugins Dcc dccget] $file \
-      00 $usr $leng $posn <@$sk 2>@$sk" r} fd] {
-	tellError {} {Prog error} "Cannot run DCC helper program dccget - $fd. Check your installation"
-    } {
-	upvar #0 Get$net Get
-	catch {fconfigure $fd -buffering line -translation {lf lf}}
-	fileevent $fd readable "handleInfo $net $fd"
-	$usr ref
-	lappend Get($usr) [list $fd $file $fd]
-	if [winfo exists .@dls$net] { buildDCCList $net }
-	dccWindow $fd $usr Get $file
+    catch {uplevel #0 unset tl($conn)}
+    switch $type Get {
+        switch {} $args {} default {
+	    if {[lindex $args 0]} { $net fileProcess $file $who }
+	}
     }
-    close $sk
 }
 #
 proc dccAutoDir {net fln} {
     foreach x [$net autogetdir] {
 	set dir [lindex $x 0]
 	switch {} [set rx [lindex $x 1]] {set rx .*}
-	if [regexp $rx $fln] {return $dir}
+	if {[regexp $rx $fln]} {return $dir}
     }
     return {}
 }
@@ -141,28 +100,32 @@ switch -glob [info tclversion] {
 #
 proc handleSend {net fln usr addr port leng posn auto} {
     global GetDir zFileTypes
-    if $auto {
+    if {$auto} {
 	switch {} [set fl [dccAutoDir $net $fln]] {} default {
 	    doGetDCC $net Get $usr $addr $port $leng $posn \
 		[file join $fl $fln]
 	    return
 	}
     }
-    if ![info exists GetDir($net)] {
+    if {![info exists GetDir($net)]} {
 	switch {} [set GetDir($net) [dccAutoDir $net $fln]] {
 	    set GetDir($net) [pwd]
 	}
     }
     set dir $GetDir($net)
     set msg "DCC Send request ($fln) from [$usr name]"
-    set fl [tk_getSaveFile -initialdir $dir -initialfile $fln -filetypes $zFileTypes]
-    set GetDir($net) [file dirname $fl]
-    doGetDCC $net Get $usr $addr $port $leng $posn $fl
+    switch {} [set fl [tk_getSaveFile -initialdir $dir -initialfile $fln \
+      -filetypes $zFileTypes]] {
+# user cancelled the op. Should we do something?
+    } default {
+	set GetDir($net) [file dirname $fl]
+	doGetDCC $net Get $usr $addr $port $leng $posn $fl
+    }
 }
 }
 default {
 proc handleSend {net fln usr addr port leng posn auto} {
-    if $auto {
+    if {$auto} {
 	switch {} [set fl [dccAutoDir $net $fln]] {} default {
 	    doGetDCC $net Get $usr $addr $port $leng $posn \
 		[file join $fl $fln]
@@ -170,7 +133,7 @@ proc handleSend {net fln usr addr port leng posn auto} {
 	}
     }
     global GetDir
-    if ![info exists GetDir($net)] {
+    if {![info exists GetDir($net)]} {
 	switch {} [set GetDir($net) [dccAutoDir $net $fln]] {
 		set GetDir($net) [pwd]
 	}
@@ -187,7 +150,7 @@ proc handleResume {net usr file port posn} {
     upvar #0 Offer$net Offer
     set i 0
     set fnd 0
-    if ![info exists Offer($usr)] {
+    if {![info exists Offer($usr)]} {
 	warnUser {Resume Error} "Asked to Resume, but no DCC offer to [$usr name] outstanding!"
     } {
 	foreach l $Offer($usr) {
@@ -200,7 +163,7 @@ proc handleResume {net usr file port posn} {
 	    }
 	    incr i
 	}
-	if !$fnd {
+	if {!$fnd} {
 	    warnUser {Resume Error} "Asked to Resume, but cannot find matching offer to [$usr name]!"
 	}
     }
@@ -208,22 +171,25 @@ proc handleResume {net usr file port posn} {
 #
 proc handleAccept {net usr fln port posn} {
     global Resume
-    set i 0
-    foreach l $Resume($usr) {
-	switch $port [lindex $l 2] {
-	    foreach {file addr port leng posn} $l break
-	    doGetDCC $net Get $usr $addr $port $leng $posn $file
-	    $usr deref
-	    listdel Resume($usr) $i
-	    switch {} $Resume($usr) {unset Resume($usr)}
-	    break
+    if {![info exists Resume($usr)]} {
+	    warnUser {Resume Error} "Asked to Accept a resume, but cannot find matching offer to [$usr name]!"
+    } {
+	set i 0
+	foreach l $Resume($usr) {
+	    switch $port [lindex $l 2] {
+		foreach {file addr port leng posn} $l break
+		doGetDCC $net Get $usr $addr $port $leng $posn $file
+		listdel Resume($usr) $i
+		switch {} $Resume($usr) {unset Resume($usr)}
+		break
+	    }
+	    incr i
 	}
-	incr i
     }
 }
 #
 proc dccWindow {conn usr array file} {
-    if [winfo exists [set w .@$conn]] return
+    if {[winfo exists [set w .@$conn]]} return
     toplevel $w -class Zircon
     switch $array Send {
 	wm title $w "DCC send $file to [$usr name]"
